@@ -1,7 +1,7 @@
 from flask import Blueprint, request
-from flask_restful import Resource, Api
+from flask_restful import Api
 from .common import Status, WorkMode, Manifest, DiffMode
-from .flow import Flow, FlowList, FlowFilter
+from .flow import Flow, FlowList
 from .mock import MockData, MockGroup, ActivatedMockGroup, MockGroupByName, MockDataLabel
 from .config import Conf
 from .menu import Menu
@@ -17,8 +17,6 @@ from .status_bar import StatusBar
 from .snapshot import SnapshotImport, SnapshotExport, Snapshot
 from lyrebird.log import get_logger
 from lyrebird import application
-from flask import got_request_exception
-import traceback
 
 
 logger = get_logger()
@@ -46,8 +44,7 @@ def on_500(error):
 api_source.add_resource(Status, '/status')
 api_source.add_resource(Manifest, '/manifest')
 api_source.add_resource(Flow, '/flow/<string:id>')
-api_source.add_resource(FlowList, '/flow')
-api_source.add_resource(FlowFilter, '/flowfilter')
+api_source.add_resource(FlowList, '/flow', '/flow/<string:action>')
 api_source.add_resource(Cut, '/cut/<string:_id>')
 api_source.add_resource(Copy, '/copy/<string:_id>')
 api_source.add_resource(Paste, '/paste/<string:_id>')
