@@ -74,7 +74,7 @@ class ProxyHandler:
 
         # 增加数据源标记，此数据经代理得到
         resp_headers = [('lyrebird', 'proxy')]
-        for name, value in r.headers.items():
+        for name, value in r.raw.headers.items():
             # rm 'content-length' from ignore list
             if name.lower() in ('content-encoding',
                                 'transfer-encoding'):
