@@ -40,8 +40,6 @@ def to_mock_server(flow: http.HTTPFlow):
     
     flow.request.headers['Lyrebird-Client-Address'] = address
     flow.request.headers['Mitmproxy-Proxy'] = address
-    # 获取原始的请求host，加入Header key:Host, 用于重定向
-    flow.request.headers['Host'] = raw_host
     flow.request.headers['Proxy-Raw-Headers'] = json.dumps({name: flow.request.headers[name] for name in flow.request.headers}, ensure_ascii=False)
 
     _logger.info('Redirect-> %s' % flow.request.url[:100])
@@ -77,14 +75,3 @@ def responseheaders(flow):
     command = flow.response.headers.get('Lyrebird-Mitmproxy-Command')
     if command == 'kill':
         flow.kill()
-    _recover_response_header_location(flow.response.headers)
-
-
-def _recover_response_header_location(response_header):
-    """
-        Recover response header key <Location>’s raw value for redirect against cookie missing.
-    """
-    raw_location = response_header.get('Raw-Location')
-    if raw_location:
-        response_header.update({'Location': raw_location})
-        response_header.pop('Raw-Location')
